#
# spec file for package 
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           czmq
Version:        3.0.2
Release:        3.3
License:        MPL-2.0
Summary:        High-level C binding for ØMQ
Url:            https://github.com/zeromq/czmq
Group:          Development/Libraries/C and C++
Source0:        http://download.zeromq.org/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig(libzmq) > 4.1
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkg-config
BuildRequires:  libtool
BuildRequires:  autoconf
BuildRequires:  automake
# documentation
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  xz

%description
CZMQ has these goals:

 * To wrap the ØMQ core API in semantics that lead to shorter, more readable applications.
 * To hide as far as possible the differences between different versions of ØMQ (2.x, 3.x, 4.x).
 * To provide a space for development of more sophisticated API semantics.
 * To wrap the ØMQ security features with high-level tools and APIs.
 * To become the basis for other language bindings built on top of CZMQ.

%package -n lib%{name}3
Summary:    Shared library of %{name}
Group:      Development/Languages/C and C++

%description -n lib%{name}3
This package contain shared library of %{name}.

%package devel
Summary:    Devel files for %{name}
Group:      Development/Languages/C and C++
Requires:   lib%{name}3 = %{version}

%description devel
Development files (headers, pkgconfig, cmake) for %{name}.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

rm -f %{buildroot}/%{_bindir}/*.gsl
rm -f %{buildroot}/%{_libdir}/*.la

#WORKADOUND: https://github.com/zeromq/czmq/issues/1038
rm %{buildroot}/%{_bindir}/makecert
rm %{buildroot}/%{_mandir}/man1/makecert.*

%post -n lib%{name}3 -p /sbin/ldconfig

%postun -n lib%{name}3 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE
#WORKADOUND: https://github.com/zeromq/czmq/issues/1038
# % {_bindir}/makecert

%files -n lib%{name}3
%defattr(-,root,root)
%{_libdir}/lib%{name}.so.*

%files devel
%defattr(-,root,root)
%doc AUTHORS CONTRIBUTING.md LICENSE NEWS README.md README.txt
%{_includedir}/*.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
#WORKADOUND: https://github.com/zeromq/czmq/issues/1038
# % {_mandir}/man1/makecert.1.gz
%{_mandir}/man3/z*.3.gz
%{_mandir}/man7/%{name}.7.gz

%changelog
* Tue Jul  7 2015 mvyskocil@opensuse.org
- Do not install makecert to workaround the conflict between
  czmq and mono-devel
* Tue Jul  7 2015 mvyskocil@opensuse.org
- Correct License tag to MPL-2.0
* Thu Jul  2 2015 mvyskocil@opensuse.org
- Update to 3.0.2
  * https://github.com/zeromq/czmq/issues/1021
* Mon Jun  8 2015 mvyskocil@opensuse.org
- Update to 3.0.1
  * New zsock class that works without contexts, and has smart
  constructors (create and connect/bind in one step).
  * New zactor class for multithreaded development, evolved from
  old zthread attached threads.
  * New zgossip discovery service.
  * New zrex class for regular expressions.
  * New process management functions in zsys.
- These V2 classes are deprecated:
  * zauth (rewritten as actor)
  * zbeacon (rewritten as actor)
  * zctx (deprecated)
  * zmonitor (rewritten as actor)
  * zmutex (deprecated)
  * zproxy (rewritten as actor)
  * zsocket (deprecated by zsock)
  * zsockopt (deprecated by zsock_option)
  * zthread (deprecated by zactor)
* Tue Jan 27 2015 mvyskocil@opensuse.org
- Update to 3.0.0~git.1422214591.ab92619, bugfixes
* Fri Jan 16 2015 jengelh@inai.de
- Request xz package for rpm, since source is xz archive.
* Thu Jan  8 2015 mvyskocil@opensuse.org
- Need libzmq >= 4.2, needed for malamute broker
* Thu Jan  8 2015 mvyskocil@opensuse.org
- Update to czmq-3.0.0~git.1420493785.71863a3
  * add zlistx/zhashx to provide better API than existing zlist/shash
  * czmq_selftest is no longer installed
  * remove internal usage of deprecated zsocket
  * regenerates zgossip engine/codec using latest zproto
  * speedup of zsock_send/recv
  * add move NULL checks, memory leak fixes and so
* Tue Nov  4 2014 mvyskocil@opensuse.org
- Update to czmq-3.0.0~git.1415022110.59a4f16
  * add zclock_usecs at least
* Thu Oct 16 2014 mvyskocil@opensuse.org
- Update to rc version of 3.0.0 3.0.0~git.1413364181.4d79b31
* Thu Sep 18 2014 mvyskocil@opensuse.org
- Initial packaging of czmq for openSUSE
